@@ -33,9 +33,8 @@ async fn user() {
         users.iter().any(|u| u.login.as_ref().unwrap() == "Pipis"),
         "could not find new user"
     );
-    let query = AdminGetAllEmailsQuery::default();
     let users = api
-        .admin_get_all_emails(query)
+        .admin_get_all_emails()
         .await
         .expect("failed to search emails");
     assert!(
@@ -44,6 +43,21 @@ async fn user() {
             .any(|u| u.email.as_ref().unwrap() == "pipis@noreply.example.org"),
         "could not find new user"
     );
+    let rename_opt = RenameUserOption {
+        new_username: "Bepis".into(),
+    };
+    api.admin_rename_user("Pipis", rename_opt)
+        .await
+        .expect("failed to rename user");
+    let query = AdminDeleteUserQuery { purge: Some(true) };
+    api.admin_delete_user("Bepis", query)
+        .await
+        .expect("failed to delete user");
+    let query = AdminDeleteUserQuery { purge: Some(true) };
+    assert!(
+        api.admin_delete_user("Ghost", query).await.is_err(),
+        "deleting fake user should fail"
+    );
 }
 
 #[tokio::test]
@@ -82,26 +96,10 @@ async fn org() {
         .admin_create_org("OrgOwner", org_opt)
         .await
         .expect("failed to create org");
-    let query = AdminGetAllOrgsQuery::default();
     assert!(
-        !api.admin_get_all_orgs(query).await.unwrap().1.is_empty(),
+        !api.admin_get_all_orgs().await.unwrap().1.is_empty(),
         "org list empty"
     );
-    let rename_opt = RenameUserOption {
-        new_username: "Bepis".into(),
-    };
-    api.admin_rename_user("Pipis", rename_opt)
-        .await
-        .expect("failed to rename user");
-    let query = AdminDeleteUserQuery { purge: Some(true) };
-    api.admin_delete_user("Bepis", query)
-        .await
-        .expect("failed to delete user");
-    let query = AdminDeleteUserQuery { purge: Some(true) };
-    assert!(
-        api.admin_delete_user("Ghost", query).await.is_err(),
-        "deleting fake user should fail"
-    );
 }
 
 #[tokio::test]
@@ -135,7 +133,7 @@ async fn key() {
         .admin_create_public_key("KeyHolder", key_opt)
         .await
         .expect("failed to create key");
-    api.admin_delete_user_public_key("KeyHolder", key.id.unwrap() as u64)
+    api.admin_delete_user_public_key("KeyHolder", key.id.unwrap())
         .await
         .expect("failed to delete key");
 }
@@ -144,9 +142,8 @@ async fn key() {
 async fn cron() {
     let api = common::login();
 
-    let query = AdminCronListQuery::default();
     let (_, crons) = api
-        .admin_cron_list(query)
+        .admin_cron_list()
         .await
         .expect("failed to get crons list");
     api.admin_cron_run(crons.first().expect("no crons").name.as_ref().unwrap())
@@ -181,10 +178,10 @@ async fn hook() {
         config: None,
         events: None,
     };
-    api.admin_edit_hook(hook.id.unwrap() as u64, edit_hook)
+    api.admin_edit_hook(hook.id.unwrap(), edit_hook)
         .await
         .expect("failed to edit hook");
-    api.admin_delete_hook(hook.id.unwrap() as u64)
+    api.admin_delete_hook(hook.id.unwrap())
         .await
         .expect("failed to delete hook");
 }
