@@ -3,6 +3,7 @@ use forgejo_api::structs::*;
 mod common;
 
 use common::{basic_org_repo, basic_repo, Git};
+use futures::{StreamExt, TryStreamExt};
 
 #[tokio::test]
 async fn pull_request() {
@@ -42,7 +43,7 @@ async fn pull_request() {
         .expect("couldn't create pr");
 
     let is_merged = api
-        .repo_pull_request_is_merged("TestingAdmin", "pr-test", pr.number.unwrap() as u64)
+        .repo_pull_request_is_merged("TestingAdmin", "pr-test", pr.number.unwrap())
         .await
         .is_ok();
     assert!(!is_merged, "pr should not yet be merged");
@@ -52,7 +53,7 @@ async fn pull_request() {
         .repo_get_pull_request_files(
             "TestingAdmin",
             "pr-test",
-            pr.number.unwrap() as u64,
+            pr.number.unwrap(),
             pr_files_query,
         )
         .await
@@ -69,16 +70,11 @@ async fn pull_request() {
         merge_when_checks_succeed: None,
     };
 
-    api.repo_merge_pull_request(
-        "TestingAdmin",
-        "pr-test",
-        pr.number.unwrap() as u64,
-        merge_opt,
-    )
-    .await
-    .expect("couldn't merge pr");
+    api.repo_merge_pull_request("TestingAdmin", "pr-test", pr.number.unwrap(), merge_opt)
+        .await
+        .expect("couldn't merge pr");
     let is_merged = api
-        .repo_pull_request_is_merged("TestingAdmin", "pr-test", pr.number.unwrap() as u64)
+        .repo_pull_request_is_merged("TestingAdmin", "pr-test", pr.number.unwrap())
         .await
         .is_ok();
     assert!(is_merged, "pr should be merged");
@@ -139,7 +135,7 @@ async fn release() {
     api.repo_edit_release(
         "TestingAdmin",
         "release-test",
-        release.id.unwrap() as u64,
+        release.id.unwrap(),
         edit_release,
     )
     .await
@@ -159,8 +155,8 @@ async fn release() {
         .repo_create_release_attachment(
             "TestingAdmin",
             "release-test",
-            release.id.unwrap() as u64,
-            Some(b"This is a file!".to_vec()),
+            release.id.unwrap(),
+            Some(b"This is a file!"),
             None,
             RepoCreateReleaseAttachmentQuery {
                 name: Some("test.txt".into()),
@@ -173,8 +169,8 @@ async fn release() {
             .download_release_attachment(
                 "TestingAdmin",
                 "release-test",
-                release.id.unwrap() as u64,
-                attachment.id.unwrap() as u64
+                release.id.unwrap(),
+                attachment.id.unwrap()
             )
             .await
             .unwrap()
@@ -194,13 +190,13 @@ async fn release() {
     api.repo_delete_release_attachment(
         "TestingAdmin",
         "release-test",
-        release.id.unwrap() as u64,
-        attachment.id.unwrap() as u64,
+        release.id.unwrap(),
+        attachment.id.unwrap(),
     )
     .await
     .expect("failed to deleted attachment");
 
-    api.repo_delete_release("TestingAdmin", "release-test", release.id.unwrap() as u64)
+    api.repo_delete_release("TestingAdmin", "release-test", release.id.unwrap())
         .await
         .expect("failed to delete release");
 
@@ -280,7 +276,20 @@ async fn team_pr_review_request() {
         .repo_get_pull_request("team-review-org", "team-pr-review", 1)
         .await
         .expect("couldn't get pr");
-    assert_eq!(pr.requested_reviewers, None);
+    assert_eq!(pr.requested_reviewers, Some(vec![]));
+
+    let team_name = api
+        .org_list_teams("team-review-org")
+        .all()
+        .await
+        .expect("failed to list teams")
+        .pop()
+        .and_then(|team| team.name);
+    assert_eq!(
+        pr.requested_reviewers_teams
+            .and_then(|mut teams| teams.pop()?.name),
+        team_name
+    );
 }
 
 #[tokio::test]
@@ -309,7 +318,7 @@ async fn tag_protection() {
         .as_deref()
         .expect("protection does not have pattern");
     assert_eq!(pattern, "v*");
-    let id = new_protection.id.expect("protection does not have id") as u32;
+    let id = new_protection.id.expect("protection does not have id");
 
     let protection_get = api
         .repo_get_tag_protection("TestingAdmin", "tag-protect", id)
@@ -343,9 +352,8 @@ async fn repo_vars() {
     let git = Git::new("./test_repos/repo-vars");
     let _ = basic_repo(&api, &git, "repo-vars").await;
 
-    let query = GetRepoVariablesListQuery::default();
     let (_, var_list) = api
-        .get_repo_variables_list("TestingAdmin", "repo-vars", query)
+        .get_repo_variables_list("TestingAdmin", "repo-vars")
         .await
         .expect("failed to list repo vars");
     assert!(var_list.is_empty());
@@ -383,3 +391,75 @@ async fn repo_vars() {
         .await
         .expect("failed to delete repo var");
 }
+
+#[tokio::test]
+async fn many_repos() {
+    use futures::stream::StreamExt;
+    let api = common::login();
+
+    for i in 0..100 {
+        let opts = CreateRepoOption {
+            auto_init: None,
+            default_branch: None,
+            description: None,
+            gitignores: None,
+            issue_labels: None,
+            license: None,
+            name: format!("many-repos-{i}"),
+            object_format_name: None,
+            private: None,
+            readme: None,
+            template: None,
+            trust_model: None,
+        };
+        api.create_current_user_repo(opts).await.unwrap();
+    }
+
+    let mut stream = api
+        .user_current_list_repos(UserCurrentListReposQuery { order_by: None })
+        .stream();
+    while let Some(repo) = stream.next().await {
+        let repo = repo.expect("failed to list repos");
+        eprintln!("{}", repo.full_name.as_deref().unwrap_or("missing name"));
+    }
+}
+
+#[tokio::test]
+async fn combined_status_list() {
+    let api = common::login();
+    let git = Git::new("./test_repos/combined-status-list");
+    let _ = basic_repo(&api, &git, "combined-status-list").await;
+    tokio::time::sleep(std::time::Duration::from_secs(3)).await;
+    let sha = api
+        .repo_get_branch("TestingAdmin", "combined-status-list", "main")
+        .await
+        .expect("failed to get main branch")
+        .commit
+        .expect("main branch does not have commit data")
+        .id
+        .expect("commit did not have id");
+
+    for i in 0..100 {
+        let opts = CreateStatusOption {
+            context: Some(format!("Status #{i}")),
+            description: Some(format!("This is commit status #{i}")),
+            state: Some(CommitStatusState::Success),
+            target_url: None,
+        };
+        api.repo_create_status("TestingAdmin", "combined-status-list", &sha, opts)
+            .await
+            .expect("failed to create commit status");
+    }
+
+    let statuses = api
+        .repo_get_combined_status_by_ref("TestingAdmin", "combined-status-list", &sha)
+        .stream_pages()
+        .map_ok(|page| page.statuses.expect("statuses missing from page"))
+        .map_ok(|page| futures::stream::iter(page).map(Result::<_, eyre::Report>::Ok))
+        .try_flatten()
+        .try_collect::<Vec<_>>()
+        .await
+        .expect("failed to get combined status list");
+
+    assert_eq!(statuses.len(), 100);
+}
